@@ -19,7 +19,7 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
-import asyncio
+
 from typing import (
     Optional,
     Union,
@@ -32,8 +32,7 @@ import aiohttp
 
 from .exceptions import APIException,NoToken
 from .utils import APIBaseURL,requires_token
-
-
+from .moduleinfo import __version__
 
 
 class WaifuAioClient:
@@ -41,7 +40,7 @@ class WaifuAioClient:
         self,
         session: aiohttp.ClientSession = None,
         token: Optional[str] = None,
-        appname: Optional[str] = None,
+        appname = f'aiohttp/{aiohttp.__version__}; waifuim.py/{__version__}'
 
     ):
         """Asynchronous wrapper client for waifu.im API.
@@ -58,9 +57,20 @@ class WaifuAioClient:
     async def __aenter__(self):
         return self
 
-    async def __aexit__(self, exception_type, exception, exception_traceback):
+    async def __aexit__(
+        self,
+        exception_type,
+        exception,
+        exception_traceback
+    ) -> None:
         await self.close()
 
+
+    def _create_params(self,**kwargs):
+        rt={k:','.join(i) if isinstance(i, list) else str(i) for k,i in kwargs.items() if i}
+        if rt:
+            return rt
+
     async def close(self) -> None:
         """Closes the aiohttp session (call it when you're sure you wont do any request anymore)."""
         if self.session is not None:
@@ -71,30 +81,47 @@ class WaifuAioClient:
             self.session=aiohttp.ClientSession()
         return self.session
 
-    async def _make_request(self, url: str, method: str, *args, **kwargs):
+    async def _make_request(
+        self,
+        url: str,
+        method: str,
+        *args,
+        **kwargs
+    ):
         response = await getattr(await self._get_session(), method)(url, *args, **kwargs)
         infos= await response.json()
         if response.status==200:
             return infos
         else:
-            raise APIException(response.status,infos['message'])
+            raise APIException(response.status, infos['message'])
 
-    def _create_params(self,**kwargs):
-        rt={k:','.join(i) if isinstance(i,list) else str(i) for k,i in kwargs.items() if i}
-        if rt:
-            return rt
-
-    async def _fetchtag(self, type_, tag, raw, exclude, gif, many,top):
+    async def _fetchtag(
+        self,
+        type_,
+        tag,
+        raw,
+        exclude,
+        gif,
+        many,
+        top
+    ):
         """process the request for a specific tag and check if everything is correct."""
-        params=self._create_params(exclude=exclude,gif=gif,many=many,top=top)
-        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None})
-        infos= await self._make_request(f"{APIBaseURL}{type_}/{tag}/",'get',params=params,headers=headers)
+        params=self._create_params(exclude = exclude, gif = gif, many = many, top = top)
+        headers=self._create_params(**{'User-Agent': self.appname})
+        infos= await self._make_request(f"{APIBaseURL}{type_}/{tag}/", 'get', params = params, headers = headers)
         if raw:
             return infos
-        return [im.get('url') for im in infos.get('tags')[0].get('images')] if many else infos.get('tags')[0].get('images')[0].get('url')
+        return [im['url'] for im in infos['tags'][0]['images']] if many else infos['tags'][0]['images'][0]['url']
 
-
-    async def sfw(self, tag: Union[int,str], raw: bool=False, exclude: List[str]=None, gif: bool=None, many: bool=None, top: bool=None):
+    async def sfw(
+        self,
+        tag: Union[int, str],
+        raw: bool = False,
+        exclude: List[str] = None,
+        gif: bool = None,
+        many: bool = None,
+        top: bool = None
+    ) -> Dict:
         """Gets a single or multiple unique SFW images of the specific category.
         Args:
             tag: The tag to request.
@@ -110,10 +137,17 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        data = await self._fetchtag('sfw',tag,raw,exclude,gif,many,top)
+        data = await self._fetchtag('sfw', tag, raw, exclude, gif, many, top)
         return data
 
-    async def nsfw(self, tag: Union[int,str], raw: bool=False, exclude: List[str]=None, gif: bool=None, many: bool=None, top: bool=None):
+    async def nsfw(
+        self,
+        tag : Union[int, str], raw: bool = False,
+        exclude : List[str] = None,
+        gif : bool = None,
+        many : bool = None,
+        top : bool = None
+    ) -> Dict:
         """Gets a single or multiple unique NSFW (Not Safe for Work) images of the specific category.
         Args:
             tag: The tag to request.
@@ -129,10 +163,17 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        return await self._fetchtag('nsfw',tag,raw,exclude,gif,many,top)
+        return await self._fetchtag('nsfw', tag, raw, exclude, gif, many, top)
 
     @requires_token
-    async def fav(self, user_id: str=None,toggle : List[str]=None,insert: List[str]=None, delete: List[str]=None, token: str=None):
+    async def fav(
+        self,
+        user_id : str = None,
+        toggle : List[str] = None,
+        insert : List[str] = None,
+        delete : List[str] = None,
+        token : str = None
+    ) -> Dict:
         """Get your favorite gallery.""
 
         Kwargs:
@@ -146,23 +187,22 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        params=self._create_params(user_id=user_id,toggle=toggle,insert=insert,delete=delete)
-        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None,'Authorization':f'Bearer {token if token else self.token}'})
-        return await self._make_request(f"{APIBaseURL}fav/",'get',params=params,headers=headers)
+        params=self._create_params(user_id = user_id, toggle = toggle, insert = insert, delete = delete)
+        headers=self._create_params(**{'User-Agent' : self.appname, 'Authorization' : f'Bearer {token if token else self.token}'})
+        return await self._make_request(f"{APIBaseURL}fav/", 'get', params = params, headers = headers)
 
-    async def info(self,images :List[str]=None):
+    async def info(self, images : List[str] = None) -> Dict:
         """Fetch the images data (as if you where requesting a gallery containing only those images
         Kwargs:
             images : A list of images filenames to provide.
         Raises:
             APIException: If the API response contains an error.
         """
-        params=self._create_params(images=images)
-        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None})
-        return await self._make_request(f"{APIBaseURL}info/",'get',params=params,headers=headers)
+        params=self._create_params(images = images)
+        headers=self._create_params(**{'User-Agent':self.appname})
+        return await self._make_request(f"{APIBaseURL}info/", 'get', params = params, headers = headers)
 
-
-    async def endpoints(self, full=False):
+    async def endpoints(self, full = False) -> Dict:
         """Gets the API endpoints.
 
         Kwargs:
@@ -173,9 +213,9 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        params=self._create_params(full=full)
-        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None})
-        return await self._make_request(APIBaseURL+'endpoints/','get',headers=headers,params=params)
+        params=self._create_params(full = full)
+        headers=self._create_params(**{'User-Agent' : self.appname})
+        return await self._make_request(APIBaseURL + 'endpoints/', 'get', headers = headers, params = params)
 
 
 
